// Plugin de conversion Markdown pour CKEditor
class MarkdownConverter {
    constructor(editor) {
        this.editor = editor;
        this.initializePlugin();
    }

    initializePlugin() {
        // Ajouter le bouton dans la barre d'outils
        this.editor.ui.componentFactory.add('markdownConverter', locale => {
            const button = new this.editor.ui.ButtonView(locale);

            button.set({
                label: 'Convertir Markdown',
                tooltip: true,
                withText: true,
                icon: '<svg viewBox="0 0 20 20"><path d="M2 16V4h16v12H2zM4 14h12V6H4v8zm2-2V8h2v2h2V8h2l-3 3-3-3z"/></svg>'
            });

            button.on('execute', () => {
                this.convertMarkdownToHtml();
            });

            return button;
        });
    }

    convertMarkdownToHtml() {
        // Récupérer le contenu actuel
        const markdownContent = this.editor.getData();

        // Conversion des éléments Markdown basiques
        let htmlContent = markdownContent
            // Titres
            .replace(/^# (.*$)/gm, '<h1>$1</h1>')
            .replace(/^## (.*$)/gm, '<h2>$1</h2>')
            .replace(/^### (.*$)/gm, '<h3>$1</h3>')
            
            // Style de texte
            .replace(/\*\*(.*?)\*\*/g, '<strong>$1</strong>')
            .replace(/\*(.*?)\*/g, '<em>$1</em>')
            .replace(/~~(.*?)~~/g, '<del>$1</del>')
            
            // Listes
            .replace(/^\* (.*$)/gm, '<ul><li>$1</li></ul>')
            .replace(/^\d\. (.*$)/gm, '<ol><li>$1</li></ol>')
            
            // Liens
            .replace(/\[([^\]]+)\]\(([^)]+)\)/g, '<a href="$2">$1</a>')
            
            // Images
            .replace(/!\[([^\]]+)\]\(([^)]+)\)/g, '<img src="$2" alt="$1">')
            
            // Code
            .replace(/`([^`]+)`/g, '<code>$1</code>')
            .replace(/```([\s\S]*?)```/g, '<pre><code>$1</code></pre>')
            
            // Séparateurs
            .replace(/^---$/gm, '<hr>');

        // Nettoyer les balises multiples de listes
        htmlContent = htmlContent
            .replace(/<\/ul><ul>/g, '')
            .replace(/<\/ol><ol>/g, '');

        // Mise à jour du contenu de l'éditeur
        this.editor.setData(htmlContent);
    }
}

// Déclaration du plugin
ClassicEditor.builtinPlugins.push(MarkdownConverter);

// Configuration pour activer le plugin
ClassicEditor.defaultConfig = {
    ...ClassicEditor.defaultConfig,
    toolbar: {
        items: [
            ...ClassicEditor.defaultConfig.toolbar.items,
            'markdownConverter'
        ]
    }
};